@@ -29,6 +29,13 @@ import java.util.List;
 import java.util.Stack;
 
 /**
+ * A converter which convert attribute and return values
+ * into a JSON representation. It uses certain handlers for this which
+ * are registered programatically in the constructor.
+ *
+ * Each handler gets a reference to this converter object so that it
+ * can use it for a recursive solution of nested objects.
+ *
  * @author roland
  * @since Apr 19, 2009
  */
@@ -50,7 +57,7 @@ public class AttributeToJsonConverter {
         arrayHandler = new ArrayHandler();
     }
 
-    public String convertToJson(Object pValue, JmxRequest pRequest) {
+    public JSONObject convertToJson(Object pValue, JmxRequest pRequest) {
         Stack<String> extraStack = new Stack<String>();
         List<String> extraArgs = pRequest.getExtraArgs();
         if (extraArgs != null) {
@@ -64,7 +71,7 @@ public class AttributeToJsonConverter {
         JSONObject jsonObject = new JSONObject();
         jsonObject.put("value",jsonResult);
         jsonObject.put("request",pRequest);
-        return jsonObject.toJSONString();
+        return jsonObject;
     }
 
     Object prepareForJson(Object pValue,Stack<String> pExtraArgs) {
