@@ -90,6 +90,7 @@ sub init {
     $ua->jjagent_config($self->{cfg});
     $ua->timeout($self->cfg-('timeout')) if $self->cfg('timeout');
     $ua->agent("JMX::Jmx4Perl::Agent $VERSION");
+    $ua->env_proxy;
     my $proxy = $self->cfg('proxy');
     if ($proxy) {
         if (ref($proxy) eq "HASH") {
@@ -113,7 +114,8 @@ sub request {
     my $url = $self->request_url($jmx_request);
     my $req = HTTP::Request->new(GET => $url);
     my $resp = $ua->request($req);
-    if ($resp->is_error) {
+    my $ret = from_json($resp->content());
+    if ($resp->is_error && !$ret->{status}) {
         my $error = "Error while fetching $url :\n" . $resp->status_line . "\n";
         my $content = $resp->content;
         if ($content) {
@@ -123,8 +125,8 @@ sub request {
         croak $error;
     }
     
-    my $ret = from_json($resp->content());
-    return JMX::Jmx4Perl::Response->new($jmx_request,$ret->{value});
+
+    return JMX::Jmx4Perl::Response->new($ret->{status},$jmx_request,$ret->{value},$ret->{error},$ret->{stacktrace});
 }
 
 sub request_url {
@@ -141,6 +143,8 @@ sub request_url {
         if ($type eq WRITE_ATTRIBUTE) {
             $url .= "/" . $request->get("value");
         }
+    } elsif ($type eq LIST_MBEANS) {
+        $url .= $request->get("path") if $request->get("path");
     }
     return $url;
 }
@@ -149,29 +153,6 @@ sub request_url {
 # ===================================================================
 # Specialized UserAgent for passing in credentials:
 
-package JMX::Jmx4Perl::Agent::UserAgent;
-use vars qw(@ISA);
-@ISA = qw(LWP::UserAgent);
-
-sub jjagent_config { 
-    my $self = shift;
-    $self->{jjagent_config} = shift;
-}
-
-sub get_basic_credentials { 
-    my ($self, $realm, $uri, $isproxy) = @_;
-
-    my $cfg = $self->{jjagent_config} || {};
-    my $user = $isproxy ? $cfg->{proxy_user} : $cfg->{user};
-    my $password = $isproxy ? $cfg->{proxy_password} : $cfg->{password};
-
-    if ($user && $password) {
-        return ($user,$password);
-    } else {
-        return (undef,undef);
-    }
-}
-
 =head1 LICENSE
 
 This file is part of jmx4perl.
@@ -195,4 +176,30 @@ roland@cpan.org
 
 =cut
 
+package JMX::Jmx4Perl::Agent::UserAgent;
+use vars qw(@ISA);
+@ISA = qw(LWP::UserAgent);
+
+sub jjagent_config { 
+    my $self = shift;
+    $self->{jjagent_config} = shift;
+}
+
+sub get_basic_credentials { 
+    my ($self, $realm, $uri, $isproxy) = @_;
+
+    my $cfg = $self->{jjagent_config} || {};
+    my $user = $isproxy ? $cfg->{proxy_user} : $cfg->{user};
+    my $password = $isproxy ? $cfg->{proxy_password} : $cfg->{password};
+
+    if ($user && $password) {
+        return ($user,$password);
+    } else {
+        return (undef,undef);
+    }
+}
+
+# Switch back to main package
+package JMX::Jmx4Perl::Agent;
+
 1;
