@@ -3,7 +3,7 @@
 =head1 NAME
 
 JMX::Jmx4Perl::Response - Encapsulates as JMX Response as it comes from the
-observerd Server
+observered Server
 
 =SYNOPSIS
 
@@ -19,16 +19,36 @@ use vars qw(@ISA @EXPORT);
 
 sub new {
     my $class = shift;
-    my $request = shift;
-    my $value = shift;
-
     my $self = { 
-                value => $value,
-                request => $request
+                status => shift,
+                request => shift,
+                value => shift,
                };
+    $self->{error} = $_[0] if ($_[0]);
+    $self->{stacktrace} = $_[1] if ($_[1]);
+
     return bless $self,(ref($class) || $class);
 }
 
+sub status {
+    return shift->{status};
+}
+sub is_ok {
+    return shift->{status} == 200;
+}
+
+sub is_error {
+    return shift->{status} != 200;;
+}
+
+sub error_text {
+    return shift->{error};
+}
+
+sub stacktrace {
+    return shift->{stacktrace};
+}
+
 sub value {
     return shift->{value};
 }
